This is some text.

{interactive slug="binary-cards" type="whole-page" parameters="digits=5&start=BBBBB" thumbnail="binarycards.png"}

This is some more text.

{interactive slug="arrows" type="iframe" parameters="digits=5&start=BBBBB"}

And some more text again.

{interactive slug="flying-boxes" type="in-page"}

Aaaaaaaaaaaaaaaannnnnd here's some more.
